@@ -278,22 +278,14 @@ bool AGG::Cache::ReadChunk(const std::string & key, std::vector<u8> & body)
 }
 
 /* load manual ICN object */
-void AGG::Cache::LoadExtICN(icn_cache_t & v, const ICN::icn_t icn, const u16 index, bool reflect)
+bool AGG::Cache::LoadExtICN(icn_cache_t & v, const ICN::icn_t icn, const u16 index, bool reflect)
 {
-    DEBUG(DBG_ENGINE, DBG_TRACE, ICN::GetString(icn) << ", " << index);
-
-    u8 count = 0;		// for animation sprite need update count for ICN::AnimationFrame
+    // for animation sprite need update count for ICN::AnimationFrame
+    u8 count = 0;
 
     switch(icn)
     {
-	case ICN::TELEPORT1:
-	case ICN::TELEPORT2:
-	case ICN::TELEPORT3: count = 8; break;
-	case ICN::FOUNTAIN:  count = 2; break;
-	case ICN::TREASURE:  count = 2; break;
-	case ICN::ROUTERED:  count = 145; break;
-	case ICN::YELLOW_FONT:
-	case ICN::YELLOW_SMALFONT: count = 96; break;
+	case ICN::BOAT12:		count = 1; break;
 	case ICN::BATTLESKIP:
 	case ICN::BATTLEWAIT:
 	case ICN::BATTLEAUTO:
@@ -301,12 +293,22 @@ void AGG::Cache::LoadExtICN(icn_cache_t & v, const ICN::icn_t icn, const u16 ind
 	case ICN::BUYMAX:
 	case ICN::BTNBATTLEONLY:
 	case ICN::BTNGIFT:
-	case ICN::BTNCONFIG:  count = 2; break;
-	case ICN::BOAT12:  count = 1; break;
+	case ICN::BTNCONFIG:		count = 2; break;
+	case ICN::FOUNTAIN:		count = 2; break;
+	case ICN::TREASURE:		count = 2; break;
+	case ICN::TELEPORT1:
+	case ICN::TELEPORT2:
+	case ICN::TELEPORT3:		count = 8; break;
+	case ICN::YELLOW_FONT:
+	case ICN::YELLOW_SMALFONT:	count = 96; break;
+	case ICN::ROUTERED:		count = 145; break;
 
-	default: break;
+	default: break;;
     }
 
+    if(0 == count) return false;
+    DEBUG(DBG_ENGINE, DBG_TRACE, ICN::GetString(icn) << ", " << index);
+
     if(NULL == v.sprites)
     {
 	v.sprites = new Sprite [count];
@@ -530,16 +532,21 @@ void AGG::Cache::LoadExtICN(icn_cache_t & v, const ICN::icn_t icn, const u16 ind
 	    default: break;
 	}
     }
+
+    return true;
 }
 
-bool AGG::Cache::LoadAltICN(icn_cache_t & v, const std::string & spec, const u16 index, bool reflect)
+bool AGG::Cache::LoadAltICN(icn_cache_t & v, const ICN::icn_t icn, const u16 index, bool reflect)
 {
 #ifdef WITH_XML
+    const std::string prefix_images_icn = std::string("files") + SEPARATOR + std::string("images") + SEPARATOR + String::Lower(ICN::GetString(icn));
+    const std::string xml_spec = Settings::GetLastFile(prefix_images_icn, "spec.xml");
+
     // parse spec.xml
     TiXmlDocument doc;
     const TiXmlElement* xml_icn = NULL;
 
-    if(doc.LoadFile(spec.c_str()) &&
+    if(doc.LoadFile(xml_spec.c_str()) &&
 	NULL != (xml_icn = doc.FirstChildElement("icn")))
     {
 	int count, ox, oy;
@@ -561,19 +568,19 @@ bool AGG::Cache::LoadAltICN(icn_cache_t & v, const std::string & spec, const u16
 	{
 	    xml_sprite->Attribute("ox", &ox);
 	    xml_sprite->Attribute("oy", &oy);
-	    std::string name(spec);
+	    std::string name(xml_spec);
 	    String::Replace(name, "spec.xml", xml_sprite->Attribute("name"));
 	    Sprite & sp = reflect ? v.reflect[index] : v.sprites[index];
 	    // good load
 	    if(sp.Load(name.c_str()) && sp.isValid())
 	    {
 		sp.SetOffset(ox, oy);
-		DEBUG(DBG_ENGINE, DBG_TRACE, spec << ", " << index);
+		DEBUG(DBG_ENGINE, DBG_TRACE, xml_spec << ", " << index);
 
 		return true;
 	    }
 	}
-	DEBUG(DBG_ENGINE, DBG_WARN, "broken xml file: " <<  spec);
+	DEBUG(DBG_ENGINE, DBG_WARN, "broken xml file: " <<  xml_spec);
     }
 #endif
 
@@ -654,22 +661,14 @@ void AGG::Cache::LoadICN(const ICN::icn_t icn, u16 index, bool reflect)
     const Settings & conf = Settings::Get();
     bool skip_origin = false;
 
-    // load modify sprite
-    if(ICN::isModifiedSprite(icn))
-    {
-	LoadExtICN(v, icn, index, reflect);
-	skip_origin = true;
-    }
-    else
     // load from images dir
-    if(conf.UseAltResource())
-    {
-	const std::string prefix_images_icn = std::string("files") + SEPARATOR + std::string("images") + SEPARATOR + String::Lower(ICN::GetString(icn));
-	const std::string xml_spec = Settings::GetLastFile(prefix_images_icn, "spec.xml");
-
-	if(IsFile(xml_spec) &&
-	    LoadAltICN(v, xml_spec, index, reflect)) skip_origin = true;
-    }
+    if(conf.UseAltResource() &&
+	LoadAltICN(v, icn, index, reflect))
+	skip_origin = true;
+    else
+    // load modify sprite
+    if(LoadExtICN(v, icn, index, reflect))
+	skip_origin = true;
 
     //load origin sprite
     if(!skip_origin) LoadOrgICN(v, icn, index, reflect);
@@ -941,9 +940,6 @@ void AGG::Cache::LoadFNT(void)
     else
 #endif
     {
-	PreloadObject(ICN::SMALFONT);
-	PreloadObject(ICN::FONT);
-
 	DEBUG(DBG_ENGINE, DBG_INFO, "use bitmap fonts");
     }
 }
@@ -1254,16 +1250,36 @@ void AGG::Cache::Dump(void) const
 #endif
 }
 
-// wrapper AGG::PreloadObject
-void AGG::PreloadObject(const ICN::icn_t icn, bool reflect)
+// wrapper AGG::Cache::PreloadObject
+void AGG::Cache::PreloadObject(const ICN::icn_t icn, bool reflect)
 {
     // deprecated
     // or loading all sprites? AGG::Cache::Get().LoadICN(icn, index, reflect);
 }
 
-void AGG::PreloadObject(const TIL::til_t til)
+void AGG::Cache::PreloadObject(const TIL::til_t til)
 {
-    return AGG::Cache::Get().LoadTIL(til);
+    return Get().LoadTIL(til);
+}
+
+void AGG::Cache::PreloadPalette(void)
+{
+    return Get().LoadPAL();
+}
+
+void AGG::Cache::PreloadFonts(void)
+{
+    return Get().LoadFNT();
+}
+
+void AGG::Cache::FreeObject(const ICN::icn_t icn)
+{
+    return Get().FreeICN(icn);
+}
+
+void AGG::Cache::FreeObject(const TIL::til_t til)
+{
+    return Get().FreeTIL(til);
 }
 
 void AGG::ICNRegistryEnable(bool f)
@@ -1276,16 +1292,6 @@ void AGG::ICNRegistryFreeObjects(void)
     AGG::Cache::Get().ICNRegistryFreeObjects();
 }
 
-// wrapper AGG::FreeObject
-void AGG::FreeObject(const ICN::icn_t icn)
-{
-    return AGG::Cache::Get().FreeICN(icn);
-}
-
-void AGG::FreeObject(const TIL::til_t til)
-{
-    return AGG::Cache::Get().FreeTIL(til);
-}
 
 // wrapper AGG::GetXXX
 int AGG::GetICNCount(const ICN::icn_t icn)
