@@ -225,7 +225,7 @@ void Castle::LoadFromMP2(const void *ptr)
     // fix captain
     if(building & BUILD_CAPTAIN)
     {
-	HeroBase::LoadDefaults(Skill::Primary::CAPTAIN, race, captain);
+	captain.LoadDefaults(Skill::Primary::CAPTAIN, race);
 	army.SetCommander(&captain);
     }
 
@@ -620,13 +620,36 @@ const char* Castle::GetDescriptionBuilding(u32 build, u8 race)
     return desc_build[13];
 }
 
-bool Castle::AllowBuyHero(const Heroes & hero)
+bool Castle::AllowBuyHero(const Heroes & hero, std::string* msg)
 {
-    if(Modes(DISABLEHIRES) || world.GetKingdom(GetColor()).Modes(Kingdom::DISABLEHIRES))
+    const Kingdom & myKingdom = world.GetKingdom(GetColor());
+    if(Modes(DISABLEHIRES) || myKingdom.Modes(Kingdom::DISABLEHIRES))
+    {
+	if(msg) *msg = _("Cannot recruit - you already recruit hero in current week.");
 	return false;
+    }
 
     CastleHeroes heroes = world.GetHeroes(*this);
-    return !heroes.Guest() && world.GetKingdom(color).AllowRecruitHero(true, hero.GetLevel());
+
+    if(heroes.Guest())
+    {
+	if(msg) *msg = _("Cannot recruit - you already have a Hero in this town.");
+	return false;
+    }
+
+    if(!myKingdom.AllowRecruitHero(false, hero.GetLevel()))
+    {
+	if(msg) *msg = _("Cannot recruit - you have too many Heroes.");
+	return false;
+    }
+
+    if(!myKingdom.AllowRecruitHero(true, hero.GetLevel()))
+    {
+	if(msg) *msg = _("Cannot afford a Hero");
+	return false;
+    }
+
+    return true;
 }
 
 Heroes* Castle::RecruitHero(Heroes* hero)
@@ -718,9 +741,8 @@ u16 Castle::RecruitMaxMonster(u32 dw)
 	Kingdom & kingdom = world.GetKingdom(color);
 	count = dwelling[dw_index];
 	const payment_t paymentCosts = ms.GetCost();
-	const Funds & kingdomResource = kingdom.GetFunds();
 
-	while(count && Funds(paymentCosts * count) > kingdomResource) --count;
+	while(count && kingdom.AllowPayment(paymentCosts * count)) --count;
 
 	// buy
 	if(count)
@@ -1137,7 +1159,7 @@ bool Castle::BuyBuilding(u32 build)
 		break;
 
 	    case BUILD_CAPTAIN:
-		HeroBase::LoadDefaults(Skill::Primary::CAPTAIN, race, captain);
+		captain.LoadDefaults(Skill::Primary::CAPTAIN, race);
 		if(GetLevelMageGuild()) MageGuildEducateHero(captain);
 		army.SetCommander(&captain);
 		break;
@@ -1942,6 +1964,9 @@ struct CastleHavePoint : public std::binary_function <const Castle*, const Point
 
 Castle* VecCastles::Get(s32 index) const
 {
+    if(FORMAT_VERSION_2830)
+	return world.h() ? Get(Point(index % world.w(), index / world.h())) : NULL;
+
     return Get(Point(index % world.w(), index / world.h()));
 }
 
