@@ -32,7 +32,6 @@
 #include "army.h"
 #include "bitmodes.h"
 #include "heroes.h"
-#include "game_io.h"
 #include "sprite.h"
 #include "castle_heroes.h"
 #include "position.h"
@@ -113,7 +112,7 @@ public:
     bool isCapital(void) const{ return Modes(CAPITAL); }
     bool HaveNearlySea(void) const;
     bool PresentBoat(void) const;
-    bool AllowBuyHero(const Heroes &);
+    bool AllowBuyHero(const Heroes &, std::string* = NULL);
     bool isPosition(const Point &) const;
     bool isNecromancyShrineBuild(void) const;
 
@@ -212,7 +211,6 @@ private:
     void JoinRNDArmy(void);
 
 private:
-    friend class Game::IOld;
     friend StreamBase & operator<< (StreamBase &, const Castle &);
     friend StreamBase & operator>> (StreamBase &, Castle &);
 
