@@ -315,7 +315,7 @@ void Dialog::QuickInfo(const Maps::Tiles & tile)
     // preload
     const ICN::icn_t qwikinfo = ICN::QWIKINFO;
 
-    AGG::PreloadObject(qwikinfo);
+    AGG::Cache::PreloadObject(qwikinfo);
 
     // image box
     const Sprite &box = AGG::GetICN(qwikinfo, 0);
@@ -513,7 +513,7 @@ void Dialog::QuickInfo(const Castle & castle)
     cursor.Hide();
 
     const ICN::icn_t qwiktown = ICN::QWIKTOWN;
-    AGG::PreloadObject(qwiktown);
+    AGG::Cache::PreloadObject(qwiktown);
 
     // image box
     const Sprite &box = AGG::GetICN(qwiktown, 0);
@@ -679,7 +679,7 @@ void Dialog::QuickInfo(const Heroes & hero)
     cursor.Hide();
 
     const ICN::icn_t qwikhero = ICN::QWIKHERO;
-    AGG::PreloadObject(qwikhero);
+    AGG::Cache::PreloadObject(qwikhero);
 
     // image box
     const Sprite &box = AGG::GetICN(qwikhero, 0);
