@@ -1,29 +1,30 @@
-/*************************************************************************** 
+/***************************************************************************
  *   Copyright (C) 2009 by Andrey Afletdinov <fheroes2@gmail.com>          *
  *                                                                         *
  *   Part of the Free Heroes2 Engine:                                      *
  *   http://sourceforge.net/projects/fheroes2                              *
- *                                                                         * 
- *   This program is free software; you can redistribute it and/or modify  * 
- *   it under the terms of the GNU General Public License as published by  * 
- *   the Free Software Foundation; either version 2 of the License, or     * 
- *   (at your option) any later version.                                   * 
- *                                                                         * 
- *   This program is distributed in the hope that it will be useful,       * 
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        * 
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         * 
- *   GNU General Public License for more details.                          * 
- *                                                                         * 
- *   You should have received a copy of the GNU General Public License     * 
- *   along with this program; if not, write to the                         * 
- *   Free Software Foundation, Inc.,                                       * 
- *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             * 
+ *                                                                         *
+ *   This program is free software; you can redistribute it and/or modify  *
+ *   it under the terms of the GNU General Public License as published by  *
+ *   the Free Software Foundation; either version 2 of the License, or     *
+ *   (at your option) any later version.                                   *
+ *                                                                         *
+ *   This program is distributed in the hope that it will be useful,       *
+ *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
+ *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
+ *   GNU General Public License for more details.                          *
+ *                                                                         *
+ *   You should have received a copy of the GNU General Public License     *
+ *   along with this program; if not, write to the                         *
+ *   Free Software Foundation, Inc.,                                       *
+ *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
  ***************************************************************************/
 
 #include "world.h"
 #include "agg.h"
 #include "cursor.h"
 #include "settings.h"
+#include "race.h"
 #include "game_interface.h"
 #include "kingdom.h"
 #include "maps_tiles.h"
@@ -42,7 +43,7 @@ void PlayWalkSound(Maps::Ground::ground_t ground)
 {
     M82::m82_t wav = M82::UNKNOWN;
 
-    const u8 speed = (4 > Settings::Get().Animation() ? 1 : (7 > Settings::Get().Animation() ? 2 : 3));
+    const u8 speed = (4 > Settings::Get().HeroesMoveSpeed() ? 1 : (7 > Settings::Get().HeroesMoveSpeed() ? 2 : 3));
 
     // play sound
     switch(ground)
@@ -93,7 +94,7 @@ const Sprite & SpriteHero(const Heroes & hero, const u8 index, const bool reflec
         case Race::WZRD: icn_hero = ICN::WZRD32; break;
         case Race::NECR: icn_hero = ICN::NECR32; break;
 
-        default: DEBUG(DBG_GAME , DBG_WARN, "Heroes::SpriteHero: unknown race"); break;
+        default: DEBUG(DBG_GAME, DBG_WARN, "unknown race"); break;
     }
 
     if(rotate)				index_sprite = 45;
@@ -109,7 +110,7 @@ const Sprite & SpriteHero(const Heroes & hero, const u8 index, const bool reflec
         case Direction::LEFT:           index_sprite = 18; break;
         case Direction::TOP_LEFT:       index_sprite =  9; break;
 
-        default: DEBUG(DBG_GAME , DBG_WARN, "Heroes::SpriteHero: unknown direction"); break;
+        default: DEBUG(DBG_GAME, DBG_WARN, "unknown direction"); break;
     }
 
     return AGG::GetICN(icn_hero, index_sprite + (index % 9), reflect);
@@ -129,7 +130,7 @@ const Sprite & SpriteFlag(const Heroes & hero, const u8 index, const bool reflec
         case Color::ORANGE:     icn_flag = hero.isShipMaster() ? ICN::O_BFLG32 : ICN::O_FLAG32; break;
         case Color::PURPLE:     icn_flag = hero.isShipMaster() ? ICN::P_BFLG32 : ICN::P_FLAG32; break;
 
-        default: DEBUG(DBG_GAME , DBG_WARN, "Heroes::SpriteFlag: unknown color hero"); break;
+        default: DEBUG(DBG_GAME, DBG_WARN, "unknown color"); break;
     }
 
     if(rotate)				index_sprite = 45;
@@ -145,7 +146,7 @@ const Sprite & SpriteFlag(const Heroes & hero, const u8 index, const bool reflec
         case Direction::LEFT:           index_sprite = 18; break;
         case Direction::TOP_LEFT:       index_sprite =  9; break;
 
-        default: DEBUG(DBG_GAME , DBG_WARN, "Heroes::SpriteFlag: unknown direction"); break;
+        default: DEBUG(DBG_GAME, DBG_WARN, "unknown direction"); break;
     }
 
     return AGG::GetICN(icn_flag, index_sprite + (index % 9), reflect);
@@ -167,7 +168,7 @@ const Sprite & SpriteShad(const Heroes & hero, const u8 index)
         case Direction::LEFT:           index_sprite = 54; break;
         case Direction::TOP_LEFT:       index_sprite = 63; break;
 
-        default: DEBUG(DBG_GAME , DBG_WARN, "Heroes::SpriteShadow: unknown direction"); break;
+        default: DEBUG(DBG_GAME, DBG_WARN, "unknown direction"); break;
     }
 
     return AGG::GetICN(icn_shad, index_sprite + (index % 9));
@@ -188,7 +189,7 @@ const Sprite & SpriteFroth(const Heroes & hero, const u8 index, const bool refle
         case Direction::LEFT:           index_sprite = 18; break;
         case Direction::TOP_LEFT:       index_sprite =  9; break;
 
-        default: DEBUG(DBG_GAME , DBG_WARN, "Heroes::SpriteFroth: unknown direction"); break;
+        default: DEBUG(DBG_GAME, DBG_WARN, "unknown direction"); break;
     }
 
     return AGG::GetICN(ICN::FROTH, index_sprite + (index % 9), reflect);
@@ -196,60 +197,37 @@ const Sprite & SpriteFroth(const Heroes & hero, const u8 index, const bool refle
 
 bool isNeedStayFrontObject(const Heroes & hero, const Maps::Tiles & next)
 {
-    if(hero.isShipMaster())
-        switch(next.GetObject())
-        {
-            case MP2::OBJ_WATERCHEST:
-            case MP2::OBJ_SHIPWRECKSURVIROR:
-            case MP2::OBJ_FLOTSAM:
-            case MP2::OBJ_BOTTLE:
-            case MP2::OBJ_COAST:
-            case MP2::OBJ_HEROES:
-            return true;
+    if(next.GetObject() == MP2::OBJ_CASTLE)
+    {
+	const Castle* castle = world.GetCastle(next.GetIndex());
 
-            default: break;
-        }
+	return (castle &&
+		hero.GetColor() != castle->GetColor() &&
+		    !Players::isFriends(hero.GetColor(), castle->GetColor()));
+    }
     else
-        switch(next.GetObject())
-        {
-            case MP2::OBJ_TREASURECHEST:
-            case MP2::OBJ_ANCIENTLAMP:
-            case MP2::OBJ_CAMPFIRE:
-            case MP2::OBJ_MONSTER:
-            case MP2::OBJ_RESOURCE:
-            case MP2::OBJ_ARTIFACT:
-            case MP2::OBJ_HEROES:
-            case MP2::OBJ_BOAT:
-	    case MP2::OBJ_BARRIER:
-            case MP2::OBJ_JAIL:
-            return true;
+    // to coast action
+    if(hero.isShipMaster() &&
+	next.GetObject() == MP2::OBJ_COAST)
+	return true;
 
-            case MP2::OBJ_CASTLE:
-	    {
-		const Castle *castle = world.GetCastle(next.GetIndex());
-
-		return (castle &&
-			hero.GetColor() != castle->GetColor() &&
-		        !Settings::Get().IsUnions(hero.GetColor(), castle->GetColor()));
-	    }
-	    break;
-
-            default: break;
-        }
-
-    return false;
+    return MP2::isNeedStayFront(next.GetObject());
 }
 
-void Heroes::Redraw(Surface & dst, const Interface::GameArea & gamearea, bool with_shadow) const
+void Heroes::Redraw(Surface & dst, bool with_shadow) const
 {
-    s16 dx = gamearea.GetArea().x + TILEWIDTH * (mp.x - gamearea.GetRectMaps().x);
-    s16 dy = gamearea.GetArea().y + TILEWIDTH * (mp.y - gamearea.GetRectMaps().y);
+    const Point & mp = GetCenter();
+    const Interface::GameArea & gamearea = Interface::GameArea::Get();
+    s16 dx = gamearea.GetMapsPos().x + TILEWIDTH * (mp.x - gamearea.GetRectMaps().x);
+    s16 dy = gamearea.GetMapsPos().y + TILEWIDTH * (mp.y - gamearea.GetRectMaps().y);
 
-    Redraw(dst, dx, dy, gamearea, with_shadow);
+    Redraw(dst, dx, dy, with_shadow);
 }
 
-void Heroes::Redraw(Surface & dst, const s16 dx, const s16 dy, const Interface::GameArea & gamearea, bool with_shadow) const
+void Heroes::Redraw(Surface & dst, const s16 dx, const s16 dy, bool with_shadow) const
 {
+    const Point & mp = GetCenter();
+    const Interface::GameArea & gamearea = Interface::GameArea::Get();
     if(!(gamearea.GetRectMaps() & mp)) return;
 
     bool reflect = ReflectSprite(direction);
@@ -294,40 +272,44 @@ void Heroes::Redraw(Surface & dst, const s16 dx, const s16 dy, const Interface::
 	dst_pt4.y += oy;
     }
 
-    Rect src_rt1;
-    Rect src_rt2;
-    Rect src_rt3;
-    Rect src_rt4;
+    Rect src_rt;
 
-    gamearea.SrcRectFixed(src_rt1, dst_pt1, sprite1.w(), sprite1.h());
-    gamearea.SrcRectFixed(src_rt2, dst_pt2, sprite2.w(), sprite2.h());
-    gamearea.SrcRectFixed(src_rt3, dst_pt3, sprite3.w(), sprite3.h());
-    gamearea.SrcRectFixed(src_rt4, dst_pt4, sprite4.w(), sprite4.h());
 
-    if(isShipMaster()) dst.Blit(sprite4, src_rt4, dst_pt4);
+    if(isShipMaster())
+    {
+	gamearea.SrcRectFixed(src_rt, dst_pt4, sprite4.w(), sprite4.h());
+	sprite4.Blit(src_rt, dst_pt4, dst);
+    }
 
     // redraw sprites for shadow
     if(with_shadow)
-    dst.Blit(sprite3, src_rt3, dst_pt3);
+    {
+	gamearea.SrcRectFixed(src_rt, dst_pt3, sprite3.w(), sprite3.h());
+	sprite3.Blit(src_rt, dst_pt3, dst);
+    }
 
     // redraw sprites hero and flag
-    dst.Blit(sprite1, src_rt1, dst_pt1);
-    dst.Blit(sprite2, src_rt2, dst_pt2);
+    gamearea.SrcRectFixed(src_rt, dst_pt1, sprite1.w(), sprite1.h());
+    sprite1.Blit(src_rt, dst_pt1, dst);
+
+    gamearea.SrcRectFixed(src_rt, dst_pt2, sprite2.w(), sprite2.h());
+    sprite2.Blit(src_rt, dst_pt2, dst);
 
     // redraw dependences tiles
-    const u16 center = GetIndex();
-    bool skip_ground = MP2::isActionObject(save_maps_general, isShipMaster());
+    Maps::Tiles & tile = world.GetTiles(center);
+    const s32 center = GetIndex();
+    bool skip_ground = MP2::isActionObject(tile.GetObject(false), isShipMaster());
 
-    world.GetTiles(center).RedrawTop();
+    tile.RedrawTop(dst);
 
     if(Maps::isValidDirection(center, Direction::TOP))
-	world.GetTiles(Maps::GetDirectionIndex(center, Direction::TOP)).RedrawTop4Hero(dst, gamearea, skip_ground);
+	world.GetTiles(Maps::GetDirectionIndex(center, Direction::TOP)).RedrawTop4Hero(dst, skip_ground);
 
     if(Maps::isValidDirection(center, Direction::BOTTOM))
     {
 	Maps::Tiles & tile_bottom = world.GetTiles(Maps::GetDirectionIndex(center, Direction::BOTTOM));
-	tile_bottom.RedrawBottom4Hero(dst, gamearea);
-	tile_bottom.RedrawTop(dst, gamearea);
+	tile_bottom.RedrawBottom4Hero(dst);
+	tile_bottom.RedrawTop(dst);
     }
 
     if(45 > GetSpriteIndex() &&
@@ -338,75 +320,64 @@ void Heroes::Redraw(Surface & dst, const s16 dx, const s16 dy, const Interface::
 	if(Maps::isValidDirection(Maps::GetDirectionIndex(center, direction), Direction::BOTTOM))
 	{
 	    Maps::Tiles & tile_dir_bottom = world.GetTiles(Maps::GetDirectionIndex(Maps::GetDirectionIndex(center, direction), Direction::BOTTOM));
-    	    tile_dir_bottom.RedrawBottom4Hero(dst, gamearea);
-	    tile_dir_bottom.RedrawTop(dst, gamearea);
+    	    tile_dir_bottom.RedrawBottom4Hero(dst);
+	    tile_dir_bottom.RedrawTop(dst);
 	}
 	if(Maps::isValidDirection(Maps::GetDirectionIndex(center, direction), Direction::TOP))
 	{
 	    Maps::Tiles & tile_dir_top = world.GetTiles(Maps::GetDirectionIndex(Maps::GetDirectionIndex(center, direction), Direction::TOP));
-	    tile_dir_top.RedrawTop4Hero(dst, gamearea, skip_ground);
+	    tile_dir_top.RedrawTop4Hero(dst, skip_ground);
 	}
     }
 
     if(Maps::isValidDirection(center, direction))
     {
 	if(Direction::TOP == direction)
-	    world.GetTiles(Maps::GetDirectionIndex(center, direction)).RedrawTop4Hero(dst, gamearea, skip_ground);
+	    world.GetTiles(Maps::GetDirectionIndex(center, direction)).RedrawTop4Hero(dst, skip_ground);
 	else
-	    world.GetTiles(Maps::GetDirectionIndex(center, direction)).RedrawTop(dst, gamearea);
+	    world.GetTiles(Maps::GetDirectionIndex(center, direction)).RedrawTop(dst);
     }
 }
 
+void Heroes::MoveStep(Heroes & hero, s32 index_from, s32 index_to, bool newpos)
+{
+    if(newpos)
+    {
+	hero.Move2Dest(index_to);
+	hero.GetPath().PopFront();
+
+	// possible hero is die
+	if(!hero.isFreeman() &&
+	    index_to == hero.GetPath().GetDestinationIndex())
+	{
+	    hero.GetPath().Reset();
+	    hero.Action(index_to);
+	    hero.SetMove(false);
+	}
+    }
+    else
+    {
+	hero.ApplyPenaltyMovement();
+	hero.GetPath().Reset();
+	hero.Action(index_to);
+	hero.SetMove(false);
+    }
+}
 
 bool Heroes::MoveStep(bool fast)
 {
-    u16 index_from = GetIndex();
-    u16 index_to = Maps::GetDirectionIndex(index_from, path.GetFrontDirection());
-    u16 index_dst = path.GetDestinationIndex();
+    s32 index_from = GetIndex();
+    s32 index_to = Maps::GetDirectionIndex(index_from, path.GetFrontDirection());
+    s32 index_dst = path.GetDestinationIndex();
+    const Point & mp = GetCenter();
 
     if(fast)
     {
 	if(index_to == index_dst && isNeedStayFrontObject(*this, world.GetTiles(index_to)))
-	{
-	    ApplyPenaltyMovement();
-	    path.Reset();
-	    Action(index_to);
-	    SetMove(false);
-	}
+	    MoveStep(*this, index_from, index_to, false);
 	else
-	{
-	    Maps::Tiles & tiles_from = world.GetTiles(index_from);
-	    Maps::Tiles & tiles_to = world.GetTiles(index_to);
+	    MoveStep(*this, index_from, index_to, true);
 
-	    if(MP2::OBJ_HEROES != save_maps_general) tiles_from.SetObject(save_maps_general);
-
-	    SetCenter(index_to);
-	    save_maps_general = tiles_to.GetObject();
-	    tiles_to.SetObject(MP2::OBJ_HEROES);
-	    Scoute();
-	    ApplyPenaltyMovement();
-	    path.PopFront();
-
-	    if(MP2::OBJ_EVENT == save_maps_general)
-	    {
-		Action(index_to);
-		SetMove(false);
-	    }
-
-	    // check protection tile
-	    ActionNewPosition();
-
-	    // possible hero is die
-	    if(!isFreeman())
-	    {
-		if(index_to == index_dst)
-		{
-		    path.Reset();
-		    Action(index_to);
-		    SetMove(false);
-		}
-	    }
-	}
 	return true;
     }
     else
@@ -414,67 +385,22 @@ bool Heroes::MoveStep(bool fast)
     {
 	if(index_to == index_dst && isNeedStayFrontObject(*this, world.GetTiles(index_to)))
 	{
-	    ApplyPenaltyMovement();
-	    path.Reset();
-	    Action(index_to);
-	    SetMove(false);
+	    MoveStep(*this, index_from, index_to, false);
+
 	    return true;
 	}
 	else
 	{
-	    if(Game::LOCAL == world.GetKingdom(GetColor()).Control())
 	    // play sound
-	    PlayWalkSound(world.GetTiles(mp).GetGround());
+	    if(CONTROL_HUMAN & world.GetKingdom(GetColor()).GetControl())
+		PlayWalkSound(world.GetTiles(mp).GetGround());
 	}
     }
     else
     if(8 == sprite_index % 9)
     {
-	Maps::Tiles & tiles_from = world.GetTiles(index_from);
-	Maps::Tiles & tiles_to = world.GetTiles(index_to);
-
-	if(MP2::OBJ_HEROES != save_maps_general) tiles_from.SetObject(save_maps_general);
-
-	SetCenter(index_to);
-	save_maps_general = tiles_to.GetObject();
-	tiles_to.SetObject(MP2::OBJ_HEROES);
-	Scoute();
-	ApplyPenaltyMovement();
 	sprite_index -= 8;
-	path.PopFront();
-
-	if(MP2::OBJ_EVENT == save_maps_general)
-	{
-	    Action(index_to);
-	    SetMove(false);
-	}
-
-	// check protection tile
-	ActionNewPosition();
-
-	// possible hero is die
-	if(!isFreeman())
-	{
-	    if(index_to == index_dst)
-	    {
-		path.Reset();
-		Action(index_to);
-		SetMove(false);
-	    }
-
-	    // AI: force scan resource around
-	    if(GetControl() == Game::AI)
-	    {
-		const u16 dst = Maps::ScanAroundObject(index_to, MP2::OBJ_RESOURCE);
-		for(Direction::vector_t dir = Direction::TOP_LEFT; dir < Direction::CENTER; ++dir) if(dst & dir)
-		{
-            	    if(CanMove())
-            		Action(Maps::GetDirectionIndex(index_to, dir));
-            	    else
-            		break;
-        	}
-	    }
-	}
+	MoveStep(*this, index_from, index_to, true);
 
 	return true;
     }
@@ -484,10 +410,10 @@ bool Heroes::MoveStep(bool fast)
     return false;
 }
 
-void Heroes::AngleStep(const Direction::vector_t to_direct)
+void Heroes::AngleStep(u16 to_direct)
 {
     //bool check = false;
-    bool clockwise = ShortDistanceClockWise(direction, to_direct);
+    bool clockwise = Direction::ShortDistanceClockWise(direction, to_direct);
 
     // start index
     if(45 > sprite_index && 0 == sprite_index % 9)
@@ -589,33 +515,31 @@ void Heroes::AngleStep(const Direction::vector_t to_direct)
 
 void Heroes::FadeOut(void) const
 {
+    const Point & mp = GetCenter();
     const Interface::GameArea & gamearea = Interface::GameArea::Get();
 
     if(!(gamearea.GetRectMaps() & mp)) return;
 
+    Display & display = Display::Get();
+
     bool reflect = ReflectSprite(direction);
 
-    s16 dx = gamearea.GetArea().x + TILEWIDTH * (mp.x - gamearea.GetRectMaps().x);
-    s16 dy = gamearea.GetArea().y + TILEWIDTH * (mp.y - gamearea.GetRectMaps().y);
+    s16 dx = gamearea.GetMapsPos().x + TILEWIDTH * (mp.x - gamearea.GetRectMaps().x);
+    s16 dy = gamearea.GetMapsPos().y + TILEWIDTH * (mp.y - gamearea.GetRectMaps().y);
 
     const Sprite & sprite1 = SpriteHero(*this, sprite_index, reflect);
 
-    Surface sf(sprite1.w(), sprite1.h());
-    sf.SetColorKey();
-    sf.Blit(sprite1);
-
     Point dst_pt1(dx + (reflect ? TILEWIDTH - sprite1.x() - sprite1.w() : sprite1.x()), dy + sprite1.y() + TILEWIDTH);
-    Rect src_rt1;
+    Rect src_rt;
 
-    gamearea.SrcRectFixed(src_rt1, dst_pt1, sprite1.w(), sprite1.h());
+    gamearea.SrcRectFixed(src_rt, dst_pt1, sprite1.w(), sprite1.h());
 
     LocalEvent & le = LocalEvent::Get();
-    u32 ticket = 0;
     u8 alpha = 250;
 
     while(le.HandleEvents() && alpha > 0)
     {
-        if(Game::ShouldAnimateInfrequent(ticket, 1))
+        if(Game::AnimateInfrequent(Game::HEROES_FADE_DELAY))
         {
             Cursor::Get().Hide();
 
@@ -625,13 +549,12 @@ void Heroes::FadeOut(void) const
 	    {
         	const Maps::Tiles & tile = world.GetTiles(Maps::GetIndexFromAbsPoint(x, y));
 
-        	tile.RedrawTile();
-        	tile.RedrawBottom();
-        	tile.RedrawObjects();
+        	tile.RedrawTile(display);
+        	tile.RedrawBottom(display);
+        	tile.RedrawObjects(display);
     	    }
 
-    	    sf.SetAlpha(alpha);
-    	    Display::Get().Blit(sf, src_rt1, dst_pt1);
+    	    sprite1.Blit(alpha, src_rt, dst_pt1, display);
 
 	    for(s16 y = mp.y - 1; y <= mp.y + 1; ++y)
 		for(s16 x = mp.x - 1; x <= mp.x + 1; ++x)
@@ -639,47 +562,43 @@ void Heroes::FadeOut(void) const
 	    {
         	const Maps::Tiles & tile = world.GetTiles(Maps::GetIndexFromAbsPoint(x, y));
 
-        	tile.RedrawTop();
+        	tile.RedrawTop(display);
     	    }
 
 	    Cursor::Get().Show();
-	    Display::Get().Flip();
+	    display.Flip();
             alpha -= 10;
         }
-
-        ++ticket;
     }
 }
 
 void Heroes::FadeIn(void) const
 {
+    const Point & mp = GetCenter();
     const Interface::GameArea & gamearea = Interface::GameArea::Get();
 
     if(!(gamearea.GetRectMaps() & mp)) return;
 
+    Display & display = Display::Get();
+
     bool reflect = ReflectSprite(direction);
 
-    s16 dx = gamearea.GetArea().x + TILEWIDTH * (mp.x - gamearea.GetRectMaps().x);
-    s16 dy = gamearea.GetArea().y + TILEWIDTH * (mp.y - gamearea.GetRectMaps().y);
+    s16 dx = gamearea.GetMapsPos().x + TILEWIDTH * (mp.x - gamearea.GetRectMaps().x);
+    s16 dy = gamearea.GetMapsPos().y + TILEWIDTH * (mp.y - gamearea.GetRectMaps().y);
 
     const Sprite & sprite1 = SpriteHero(*this, sprite_index, reflect);
 
-    Surface sf(sprite1.w(), sprite1.h());
-    sf.SetColorKey();
-    sf.Blit(sprite1);
-
     Point dst_pt1(dx + (reflect ? TILEWIDTH - sprite1.x() - sprite1.w() : sprite1.x()), dy + sprite1.y() + TILEWIDTH);
-    Rect src_rt1;
+    Rect src_rt;
 
-    gamearea.SrcRectFixed(src_rt1, dst_pt1, sprite1.w(), sprite1.h());
+    gamearea.SrcRectFixed(src_rt, dst_pt1, sprite1.w(), sprite1.h());
 
     LocalEvent & le = LocalEvent::Get();
-    u32 ticket = 0;
     u8 alpha = 0;
 
     while(le.HandleEvents() && alpha < 250)
     {
-        if(Game::ShouldAnimateInfrequent(ticket, 1))
+        if(Game::AnimateInfrequent(Game::HEROES_FADE_DELAY))
         {
             Cursor::Get().Hide();
 
@@ -689,13 +608,12 @@ void Heroes::FadeIn(void) const
 	    {
         	const Maps::Tiles & tile = world.GetTiles(Maps::GetIndexFromAbsPoint(x, y));
 
-        	tile.RedrawTile();
-        	tile.RedrawBottom();
-        	tile.RedrawObjects();
+        	tile.RedrawTile(display);
+        	tile.RedrawBottom(display);
+        	tile.RedrawObjects(display);
     	    }
 
-    	    sf.SetAlpha(alpha);
-    	    Display::Get().Blit(sf, src_rt1, dst_pt1);
+    	    sprite1.Blit(alpha, src_rt, dst_pt1, display);
 
 	    for(s16 y = mp.y - 1; y <= mp.y + 1; ++y)
 		for(s16 x = mp.x - 1; x <= mp.x + 1; ++x)
@@ -703,15 +621,13 @@ void Heroes::FadeIn(void) const
 	    {
         	const Maps::Tiles & tile = world.GetTiles(Maps::GetIndexFromAbsPoint(x, y));
 
-        	tile.RedrawTop();
+        	tile.RedrawTop(display);
     	    }
 
 	    Cursor::Get().Show();
-	    Display::Get().Flip();
+	    display.Flip();
             alpha += 10;
         }
-
-        ++ticket;
     }
 }
 
@@ -728,6 +644,8 @@ bool Heroes::Move(bool fast)
 	{
 	    direction = path.GetFrontDirection();
     	    MoveStep(true);
+
+	    return true;
 	}
 	else
 	{
