@@ -213,7 +213,7 @@ void World::NewMaps(const u16 sw, const u16 sh)
     width = sw;
     height = sh;
 
-    AGG::PreloadObject(TIL::GROUND32);
+    AGG::Cache::PreloadObject(TIL::GROUND32);
 
     vec_tiles.resize(width * height);
 
@@ -259,7 +259,7 @@ void World::LoadMaps(const std::string &filename)
 	 Error::Except(__FUNCTION__, "load maps");
     }
 
-    AGG::PreloadObject(TIL::GROUND32);
+    AGG::Cache::PreloadObject(TIL::GROUND32);
 
     u8   byte8;
     u16  byte16;
@@ -1122,6 +1122,10 @@ void World::NewWeek(void)
 	vec_kingdoms.AddTributeEvents(map_captureobj, day, MP2::OBJ_WINDMILL);
 	vec_kingdoms.AddTributeEvents(map_captureobj, day, MP2::OBJ_MAGICGARDEN);
     }
+
+    // new day - reset option: "heroes: remember MP/SP for retreat/surrender result"
+    std::for_each(vec_heroes.begin(), vec_heroes.end(),
+	std::bind2nd(std::mem_fun(&Heroes::ResetModes), Heroes::SAVEPOINTS));
 }
 
 void World::NewMonth(void)
@@ -1676,10 +1680,6 @@ StreamBase & operator<< (StreamBase & msg, const CapturedObject & obj)
 
 StreamBase & operator>> (StreamBase & msg, CapturedObject & obj)
 {
-    if(FORMAT_VERSION_2798 > Game::GetSaveVersion())
-    {
-	return msg >> obj.objcol >> obj.guardians;
-    }
     return msg >> obj.objcol >> obj.guardians >> obj.split;
 }
 
